@@ -28,6 +28,11 @@ class MTWandbLogger(WandbLogger):
 
 
 class MTMLflowCallback(MLflowCallbackBase):
+    def __init__(self, model_dir, pl_params, model_name):
+        self.model_dir = model_dir
+        self.pl_params = pl_params
+        self.model_name = model_name
+
     def update_mlflow_metrics(self, trainer, pl_module, phase):
         trainer_logger = trainer.logger
         trainer_loss_logger = trainer_logger.loss_logger
@@ -44,6 +49,24 @@ class MTMLflowCallback(MLflowCallbackBase):
             step=pl_module.current_epoch
         )
 
+    def register_model(self, trainer, pl_module):
+        mlflow.gluon.log_model(
+            pytorch_model=pl_module.multi_task,
+            artifact_path="model",
+            conda_env=None,
+            registered_model_name=self.model_name,
+            pip_requirements=[],
+        )
+
+    def log_artifacts_start(self, trainer, pl_module):
+        mlflow.log_params(self.pl_params)
+
+    def log_artifacts_epoch(self, trainer, pl_module):
+        pass
+
+    def log_artifacts_end(self, trainer, pl_module):
+        mlflow.log_artifacts(local_dir=self.model_dir, artifact_path=None)
+
 
 class MTTopKAccCallback(pl.callbacks.Callback):
     def __init__(self, test_dataset, top_k, device):
